@@ -227,23 +227,24 @@ const ApplicationsMenu = new Lang.Class({
     Name: 'ApplicationsMenu',
     Extends: PopupMenu.PopupMenu,
 
-    _init: function(sourceActor, arrowAlignment, arrowSide, button) {
+    _init: function(sourceActor, arrowAlignment, arrowSide, button, hotCorner) {
         this.parent(sourceActor, arrowAlignment, arrowSide);
         this._button = button;
+        this._hotCorner = hotCorner;
     },
 
     open: function(animate) {
-        this._button.hotCorner.setBarrierSize(0);
-        if (this._button.hotCorner.actor) // fallback corner
-            this._button.hotCorner.actor.hide();
+        this._hotCorner.setBarrierSize(0);
+        if (this._hotCorner.actor) // fallback corner
+            this._hotCorner.actor.hide();
         this.parent(animate);
     },
 
     close: function(animate) {
         let size = Main.layoutManager.panelBox.height;
-        this._button.hotCorner.setBarrierSize(size);
-        if (this._button.hotCorner.actor) // fallback corner
-            this._button.hotCorner.actor.show();
+        this._hotCorner.setBarrierSize(size);
+        if (this._hotCorner.actor) // fallback corner
+            this._hotCorner.actor.show();
         this.parent(animate);
     },
 
@@ -264,8 +265,9 @@ const ApplicationsButton = new Lang.Class({
 
     _init: function() {
         this.parent(1.0, null, false);
+        this._hotCorner = Main.layoutManager.hotCorners[Main.layoutManager.primaryIndex];
 
-        this.setMenu(new ApplicationsMenu(this.actor, 1.0, St.Side.TOP, this));
+        this.setMenu(new ApplicationsMenu(this.actor, 1.0, St.Side.TOP, this, this._hotCorner));
         Main.panel.menuManager.addMenu(this.menu);
 
         // At this moment applications menu is not keyboard navigable at
@@ -308,10 +310,6 @@ const ApplicationsButton = new Lang.Class({
         }));
     },
 
-    get hotCorner() {
-        return Main.layoutManager.hotCorners[Main.layoutManager.primaryIndex];
-    },
-
     _createVertSeparator: function() {
         let separator = new St.DrawingArea({ style_class: 'calendar-vertical-separator',
                                              pseudo_class: 'highlighted' });
@@ -426,7 +424,7 @@ const ApplicationsButton = new Lang.Class({
         this.leftBox = new St.BoxLayout({ vertical: true });
         this.applicationsScrollBox = new St.ScrollView({ x_fill: true, y_fill: false,
                                                          y_align: St.Align.START,
-                                                         style_class: 'apps-menu vfade' });
+                                                         style_class: 'vfade' });
         this.applicationsScrollBox.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         let vscroll = this.applicationsScrollBox.get_vscroll_bar();
         vscroll.connect('scroll-start', Lang.bind(this, function() {
